==> PhysX-4.0.zip: PhysX-4.0/physx/documentation/PhysXAPI/files/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PhysX 4.0 API Documentation", "index.html", [
    [ "PhysX License", "index.html#intro_sec", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", "functions_eval" ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"GuContactBuffer_8h.html",
"PxIO_8h.html",
"PxWindowsIntrinsics_8h.html#a39a4b10ef013902b46ab72a6f301faaf",
"classPxArticulationReducedCoordinate.html#af8b5217bd48e6d1ccc8ba3e495c66df7",
"classPxContactSet.html#a6535e80819a6d2a5bbe38db6aa86684e",
"classPxDeserializationContext.html#a393b7ca347c967d330791d19b2e37006",
"classPxJoint.html#a1da1a62c8aa565a92ff25c83825d1657",
"classPxObstacleContext.html#aaf653d99de6f092896cc1baa2a4e99c2",
"classPxRigidBody.html#aafdbdab1865112b15201aeabb23877b4",
"classPxSerialization.html#a6c64dc9a55f7ae9ffc8c1802855134ed",
"classPxTriangleMesh.html#a261ef2fa9709a163408b41d2c34dda71",
"classPxVehicleDrive.html#a255e6465bfe1f298cb22f24ede46869c",
"classPxVehicleGearsData.html#a31359110050aad08510b99208a304cb7a981cc327b2fa9709f58cea31945e610c",
"classPxVehicleWheelsSimData.html#acbe6956ae50dfadcd9264ed9830da207",
"globals_func.html",
"group__extensions.html#gaade73cffb9e3e77ae5457c3d393d481e",
"group__foundation.html#ga7bd33cbf0ea64aee9a79758f70050cdf",
"group__geomutils.html#ga9bff69ddd57aac22aad966a4b30983e7",
"group__vehicle.html#ga8d4cfac998db5828bcfff2253c3d1fcc",
"structPxConstraintFlag.html#a86960e99b3e80ddb9e0ab51d7afc3427a8e00c572e54f3575284ff41432f1bec6",
"structPxConvexMeshCookingResult.html#ac1c7b1cbfc80b0af00bec95faf1ebf42aefc22064dc3a0abe956c25394a5261d2",
"structPxHitCallback.html#a8ff687b42ac0273e730c714bf66dae49",
"structPxRigidBodyData.html#adbfbf35988384b74c8c9fa4280a7c45b",
"structPxVehicleDriveTankWheelOrder.html#ad777dedf3db655580fb92de098646cb7a5cb2b2d8c58576c6a746d8ce8749808e"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> PhysX-4.0.0.zip: PhysX-4.0.0/physx/documentation/PhysXAPI/files/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PhysX 4.0 API Documentation", "index.html", [
    [ "PhysX License", "index.html#intro_sec", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", "functions_eval" ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"GuContactBuffer_8h.html",
"PxIO_8h.html",
"PxWindowsIntrinsics_8h.html#a5d4ea7807df2fcf1968275bc06e79319",
"classPxArticulationReducedCoordinate.html#af8b5217bd48e6d1ccc8ba3e495c66df7",
"classPxContactSet.html#a6535e80819a6d2a5bbe38db6aa86684e",
"classPxDeserializationContext.html#a393b7ca347c967d330791d19b2e37006",
"classPxJoint.html#a1cfe86fe5c8131cea1b9b5ff9df7a014",
"classPxObstacleContext.html#a9390f860fb489f283c9f872af2777123",
"classPxRigidBody.html#a9e6f3afd71605e037a5de47955d941e0",
"classPxSerialization.html#a84d55e6e21727087653a70cc20557765",
"classPxTriangleMesh.html#a611c8453a6b6256a63f1450aa8cf237a",
"classPxVehicleDrive.html#a2af80cf3e4d767f1710a8f2e244cb9d5",
"classPxVehicleGearsData.html#a31359110050aad08510b99208a304cb7aa1c63bf522cfa13f31b1432c97ea5cac",
"classPxVehicleWheelsSimData.html#acefb8071acd7ce982e2eeee33ef758da",
"globals_func_c.html",
"group__extensions.html#gaade73cffb9e3e77ae5457c3d393d481e",
"group__foundation.html#ga7c72d4a195ff9acade3d092124a45c53",
"group__geomutils.html#gaa4aeb7bd1ccfedd348599061276f6d8e",
"group__vehicle.html#ga946f4d23cff6fdf36dca694641e20779",
"structPxConstraintInfo.html#a073f7587ffb496c4bdc470eb34032fd2",
"structPxConvexMeshCookingType.html#a5a2ae723aca74c185675cd7ba2c9c115a18916173251aae02128c79b69af46906",
"structPxHitFlag.html",
"structPxRigidBodyFlag.html#a5fd4878ae66a98c030a9d976e8ba8596a983c62745e575428d8b0aadefc23e8bc",
"structPxVehicleDriveTankWheelOrder.html#ad777dedf3db655580fb92de098646cb7aa54dcdaac81056baa6b9257d27df1b83"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
